# Emoji Reference Tables

This document contains tables of emoji's used by LogTools. Please use the Emoji Code when referencing emoji's in code or documentation.

## Basic Faces

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 😀 | Grinning Face | :grinning_face: |
| 😃 | Grinning Face With Big Eyes | :grinning_face_with_big_eyes: |
| 😄 | Grinning Face With Smiling Eyes | :grinning_face_with_smiling_eyes: |
| 😁 | Beaming Face With Smiling Eyes | :beaming_face_with_smiling_eyes: |
| 😅 | Grinning Face With Sweat | :grinning_face_with_sweat: |
| 😊 | Smiling Face With Smiling Eyes | :smiling_face_with_smiling_eyes: |
| 🙂 | Slightly Smiling Face | :slightly_smiling_face: |
| 😉 | Winking Face | :winking_face: |
| 😌 | Relieved Face | :relieved_face: |
| 🥰 | Smiling Face With Hearts | :smiling_face_with_hearts: |
| 😍 | Smiling Face With Heart Eyes | :smiling_face_with_heart_eyes: |
| 🤩 | Star Struck | :star_struck: |

## Emotions & Reactions

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 😢 | Crying Face | :crying_face: |
| 😭 | Loudly Crying Face | :loudly_crying_face: |
| 😤 | Face With Steam From Nose | :face_with_steam_from_nose: |
| 😠 | Angry Face | :angry_face: |
| 😡 | Enraged Face | :enraged_face: |
| 😱 | Face Screaming In Fear | :face_screaming_in_fear: |
| 🤔 | Thinking Face | :thinking_face: |
| 🤨 | Face With Raised Eyebrow | :face_with_raised_eyebrow: |
| 😐 | Neutral Face | :neutral_face: |
| 😑 | Expressionless Face | :expressionless_face: |
| 😳 | Flushed Face | :flushed_face: |
| 🥺 | Pleading Face | :pleading_face: |

## Gestures & Body Parts

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 👋 | Waving Hand | :waving_hand: |
| 👌 | OK Hand | :ok_hand: |
| 👍 | Thumbs Up | :thumbs_up: |
| 👎 | Thumbs Down | :thumbs_down: |
| 👏 | Clapping Hands | :clapping_hands: |
| 🙏 | Folded Hands | :folded_hands: |
| 👀 | Eyes | :eyes: |
| 👄 | Mouth | :mouth: |
| 🧠 | Brain | :brain: |
| 🦾 | Mechanical Arm | :mechanical_arm: |
| 🦿 | Mechanical Leg | :mechanical_leg: |

## Insects & Bugs

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 🐛 | Bug | :bug: |
| 🦋 | Butterfly | :butterfly: |
| 🐝 | Honeybee | :honeybee: |
| 🐞 | Lady Beetle | :lady_beetle: |
| 🕷️ | Spider | :spider: |
| 🦗 | Cricket | :cricket: |
| 🐜 | Ant | :ant: |

## Nature

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 🌳 | Deciduous Tree | :deciduous_tree: |
| 🌲 | Evergreen Tree | :evergreen_tree: |
| 🌵 | Cactus | :cactus: |
| 🌱 | Seedling | :seedling: |
| 🌸 | Cherry Blossom | :cherry_blossom: |
| 🌹 | Rose | :rose: |
| 🌺 | Hibiscus | :hibiscus: |
| 🌻 | Sunflower | :sunflower: |
| 🍀 | Four Leaf Clover | :four_leaf_clover: |
| ⭐ | Star | :star: |
| 🌈 | Rainbow | :rainbow: |

## Sweets & Desserts

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 🍦 | Soft Ice Cream | :soft_ice_cream: |
| 🍰 | Shortcake | :shortcake: |
| 🧁 | Cupcake | :cupcake: |
| 🍪 | Cookie | :cookie: |
| 🍫 | Chocolate Bar | :chocolate_bar: |
| 🍬 | Candy | :candy: |
| 🍭 | Lollipop | :lollipop: |

## Beverages

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 🫖 | Teapot | :teapot: |
| 🍵 | Teacup Without Handle | :teacup_without_handle: |
| 🥤 | Cup With Straw | :cup_with_straw: |
| 🧃 | Beverage Box | :beverage_box: |
| 🍺 | Beer Mug | :beer_mug: |
| 🍷 | Wine Glass | :wine_glass: |
| 🥂 | Clinking Glasses | :clinking_glasses: |

## Sports Equipment

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| ⚽ | Soccer Ball | :soccer_ball: |
| 🏀 | Basketball | :basketball: |
| 🏈 | American Football | :american_football: |
| ⚾ | Baseball | :baseball: |
| 🎾 | Tennis | :tennis: |
| 🏓 | Ping Pong | :ping_pong: |
| 🎯 | Bullseye | :bullseye: |
| 🎳 | Bowling | :bowling: |

## Activities

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 🎨 | Artist Palette | :artist_palette: |
| 🎭 | Performing Arts | :performing_arts: |
| 🎪 | Circus Tent | :circus_tent: |
| 🎤 | Microphone | :microphone: |
| 🎲 | Game Die | :game_die: |
| 🎵 | Musical Note | :musical_note: |
| 🎸 | Guitar | :guitar: |
| 🎹 | Musical Keyboard | :musical_keyboard: |
| 📚 | Books | :books: |
| 🎥 | Movie Camera | :movie_camera: |

## Ground Transportation

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 🚗 | Automobile | :automobile: |
| 🚕 | Taxi | :taxi: |
| 🚌 | Bus | :bus: |
| 🚅 | Bullet Train | :bullet_train: |
| 🚲 | Bicycle | :bicycle: |
| 🛵 | Motor Scooter | :motor_scooter: |
| 🏍️ | Motorcycle | :motorcycle: |
| 🚜 | Tractor | :tractor: |

## Air Transportation

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| ✈️ | Airplane | :airplane: |
| 🚁 | Helicopter | :helicopter: |
| 🛸 | Flying Saucer | :flying_saucer: |
| 🚀 | Rocket | :rocket: |
| 🛩️ | Small Airplane | :small_airplane: |

## Water Transportation

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 🚢 | Ship | :ship: |
| ⛵ | Sailboat | :sailboat: |
| 🛥️ | Motor Boat | :motor_boat: |
| 🚤 | Speedboat | :speedboat: |
| 🛳️ | Passenger Ship | :passenger_ship: |

## Tools

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 🔨 | Hammer | :hammer: |
| 🪛 | Screwdriver | :screwdriver: |
| 🔧 | Wrench | :wrench: |
| ⚡ | High Voltage | :high_voltage: |
| 💡 | Light Bulb | :light_bulb: |
| 🔍 | Magnifying Glass | :magnifying_glass_tilted_left: |
| 📏 | Straight Ruler | :straight_ruler: |

## Technology

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 💻 | Laptop | :laptop: |
| 🖥️ | Desktop Computer | :desktop_computer: |
| 📱 | Mobile Phone | :mobile_phone: |
| ⌚ | Watch | :watch: |
| 🖨️ | Printer | :printer: |
| 📷 | Camera | :camera: |
| 🔋 | Battery | :battery: |
| 🪫 | Low Battery | :low_battery: |
| 📡 | Satellite Antenna | :satellite_antenna: |

## Office & Communication

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 📝 | Memo | :memo: |
| 📄 | Page Facing Up | :page_facing_up: |
| 📊 | Bar Chart | :bar_chart: |
| 📈 | Chart Increasing | :chart_increasing: |
| 📉 | Chart Decreasing | :chart_decreasing: |
| 📧 | Email | :e-mail: |
| 📨 | Incoming Envelope | :incoming_envelope: |
| 📦 | Package | :package: |
| 🗂️ | Card Index Dividers | :card_index_dividers: |

## Basic Shapes & Symbols

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| 💔 | Broken Heart | :broken_heart: |
| ❤️ | Red Heart | :red_heart: |
| 💙 | Blue Heart | :blue_heart: |
| 💚 | Green Heart | :green_heart: |
| 🩶 | Grey Heart | :grey_heart: |
| 💛 | Yellow Heart | :yellow_heart: |
| 💟 | Heart Decoration | :heart_decoration: |
| ⭐ | Star | :star: |
| ✨ | Sparkles | :sparkles: |
| ⚡ | High Voltage | :high_voltage: |
| ☀️ | Sun | :sun: |
| ☁️ | Cloud | :cloud: |
| 🌈 | Rainbow | :rainbow: |
| 💲 | Heavy Dollar Sign | :heavy_dollar_sign: |
| 🟰 | Heavy Equals Sign | :heavy_equals_sign: |

## Arrows & Controls

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| ⬆️ | Up Arrow | :up_arrow: |
| ↗️ | Up-Right Arrow | :up-right_arrow: |
| ➡️ | Right Arrow | :right_arrow: |
| ↘️ | Down-Right Arrow | :down-right_arrow: |
| ⬇️ | Down Arrow | :down_arrow: |
| ↙️ | Down-Left Arrow | :down-left_arrow: |
| ⬅️ | Left Arrow | :left_arrow: |
| ↖️ | Up-Left Arrow | :up-left_arrow: |
| 🔄 | Clockwise Arrows | :clockwise_vertical_arrows: |
| ↩️ | Right Arrow Curving Left | :right_arrow_curving_left: |
| ↪️ | Left Arrow Curving Right | :left_arrow_curving_right: |
| ↕️ | Up-Down Arrow | :up-down_arrow: |
| ↔️ | Left-Right Arrow | :left-right_arrow: |
| ⤴️ | Right Arrow Curving Up | :right_arrow_curving_up: |
| ⤵️ | Right Arrow Curving Down | :right_arrow_curving_down: |
| 🛑 | Stop Sign | :stop_sign: |

## Status & Alerts

| Emoji | Emoji Name | Emoji Code |
|-------|------------|------------|
| ✅ | Check Mark Button | :check_mark_button: |
| ❌ | Cross Mark | :cross_mark: |
| ❗ | Red Exclamation Mark | :red_exclamation_mark: |
| ❓ | Red Question Mark | :red_question_mark: |
| ⚠️ | Warning | :warning: |
| 🚫 | Prohibited | :prohibited: |
| ℹ️ | Information | :information: |
| 🚧 | Construction | :construction: |
| 🚦 | Traffic Light | :vertical_traffic_light: |
| 🚀 | Rocket | :rocket: |
| 🔥 | Fire | :fire: |
| 🧨 | Firecracker | :firecracker: |